@@ -221,37 +221,38 @@ class dyn_obj:
     def apply_streamline(self, staticity, int_x, int_y, int_z, thickness):
         name = self.name+'_streamline'
         frames = self.frames
-
+        
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
-        int_coords[:, 0] = int_x
-        int_coords[:, 1] = int_y
-        int_coords[:, 2] = int_z
-
+        int_coords[:, 0] = int_x*self.scale
+        int_coords[:, 1] = int_y*self.scale
+        int_coords[:, 2] = int_z*self.scale
         int_curve = bpy.data.curves.new(name, type='CURVE')
         int_curve.dimensions = '3D'
         int_curve.resolution_u = 2
-
         # map coords to spline
         int_line = int_curve.splines.new('NURBS')
         int_line.points.add(len(int_coords))
         for i, coord in enumerate(int_coords):
             x,y,z = coord
             int_line.points[i].co = (x, y, z, 1)
-
         # create Object
         int_curveOB = bpy.data.objects.new(name, int_curve)
-
         # attach to scene and validate context
         bpy.context.collection.objects.link(int_curveOB)
 
         int_curveOB.data.bevel_depth = thickness
 
+        int_curveOB.data.use_fill_caps = True
+
+
+        int_curveOB.data.bevel_factor_start = 0
+
         if staticity == 'dynamic':
             for i in range(len(frames)):
                 cur_frame = frames[i]
-
-                bpy.data.objects[name].data.bevel_factor_end = 1/(frames[-1]+1) * cur_frame
+                
+                bpy.data.objects[name].data.bevel_factor_end = 1/(frames[-1]) * cur_frame
                 bpy.data.objects[name].data.keyframe_insert(data_path='bevel_factor_end', frame=cur_frame)
 
 class dyn_vec:
